ActionScriptElementType

Enum ActionScriptElementType 

pub enum ActionScriptElementType {
Show 176 variants Whitespace, Newline, Comment, Identifier, StringLiteral, CharLiteral, NumberLiteral, BooleanLiteral, NullLiteral, As, Break, Case, Catch, Class, Const, Continue, Default, Delete, Do, Else, Extends, False, Finally, For, Function, If, Implements, Import, In, Instanceof, Interface, Internal, Is, Native, New, Null, Package, Private, Protected, Public, Return, Static, Super, Switch, This, Throw, True, Try, Typeof, Use, Var, Void, While, With, Each, Get, Set, Namespace, Include, Dynamic, Final, Override, Array, Boolean, Date, Number, ObjectType, RegExp, StringType, Uint, Vector, VoidType, Xml, XmlList, Plus, Minus, Star, Slash, Percent, Equal, EqualEqual, EqualEqualEqual, NotEqual, NotEqualEqual, LessThan, LessEqual, GreaterThan, GreaterEqual, LogicalAnd, LogicalOr, LogicalNot, BitwiseAnd, BitwiseOr, BitwiseXor, BitwiseNot, LeftShift, RightShift, UnsignedRightShift, Increment, Decrement, PlusAssign, MinusAssign, StarAssign, SlashAssign, PercentAssign, LeftShiftAssign, RightShiftAssign, UnsignedRightShiftAssign, BitwiseAndAssign, BitwiseOrAssign, BitwiseXorAssign, Question, Colon, Dot, Arrow, LeftParen, RightParen, LeftBrace, RightBrace, LeftBracket, RightBracket, Semicolon, Comma, At, Hash, Dollar, Ampersand, Backslash, Quote, DoubleQuote, Backtick, Eof, Program, Block, Variable, FunctionCall, MethodCall, PropertyAccess, ArrayAccess, ParameterList, UseItem, ModuleItem, StructItem, EnumItem, FunctionType, Root, Statement, Expression, Assignment, ConditionalExpression, BinaryExpression, UnaryExpression, IfStatement, ForStatement, WhileStatement, DoWhileStatement, SwitchStatement, TryStatement, ThrowStatement, ReturnStatement, BreakStatement, ContinueStatement, Error, LiteralExpression, IdentifierExpression, ParenthesizedExpression, SourceFile, BlockExpression, LetStatement, IfExpression, WhileExpression, LoopExpression, ForExpression, CallExpression, IndexExpression, FieldExpression,
}
Element types for ActionScript.

Variants



Whitespace

Whitespace.



Newline

Newline.



Comment

Comment.



Identifier

Identifier.



StringLiteral

String literal.



CharLiteral

Character literal.



NumberLiteral

Number literal.



BooleanLiteral

Boolean literal.



NullLiteral

Null literal.



As

as keyword.



Break

break keyword.



Case

case keyword.



Catch

catch keyword.



Class

class keyword.



Const

const keyword.



Continue

continue keyword.



Default

default keyword.



Delete

delete keyword.



Do

do keyword.



Else

else keyword.



Extends

extends keyword.



False

false keyword.



Finally

finally keyword.



For

for keyword.



Function

function keyword.



If

if keyword.



Implements

implements keyword.



Import

import keyword.



In

in keyword.



Instanceof

instanceof keyword.



Interface

interface keyword.



Internal

internal keyword.



Is

is keyword.



Native

native keyword.



New

new keyword.



Null

null keyword.



Package

package keyword.



Private

private keyword.



Protected

protected keyword.



Public

public keyword.



Return

return keyword.



Static

static keyword.



Super

super keyword.



Switch

switch keyword.



This

this keyword.



Throw

throw keyword.



True

true keyword.



Try

try keyword.



Typeof

typeof keyword.



Use

use keyword.



Var

var keyword.



Void

void keyword.



While

while keyword.



With

with keyword.



Each

each keyword.



Get

get keyword.



Set

set keyword.



Namespace

namespace keyword.



Include

include keyword.



Dynamic

dynamic keyword.



Final

final keyword.



Override

override keyword.



Array

Array type.



Boolean

Boolean type.



Date

Date type.



Number

Number type.



ObjectType

Object type.



RegExp

RegExp type.



StringType

String type.



Uint

uint type.



Vector

Vector type.



VoidType

void type.



Xml

XML type.



XmlList

XMLList type.



Plus

+.



Minus

-.



Star

*.



Slash

/.



Percent

%.



Equal

=.



EqualEqual

==.



EqualEqualEqual

===.



NotEqual

!=.



NotEqualEqual

!==.



LessThan

<.



LessEqual

<=.



GreaterThan

>.



GreaterEqual

>=.



LogicalAnd

&&.



LogicalOr

||.



LogicalNot

!.



BitwiseAnd

&.



BitwiseOr

|.



BitwiseXor

^.



BitwiseNot

~.



LeftShift

<<.



RightShift

>>.



UnsignedRightShift

>>>.



Increment

++.



Decrement

--.



PlusAssign

+=.



MinusAssign

-=.



StarAssign

*=.



SlashAssign

/=.



PercentAssign

%=.



LeftShiftAssign

<<=.



RightShiftAssign

>>=.



UnsignedRightShiftAssign

>>>=.



BitwiseAndAssign

&=.



BitwiseOrAssign

|=.



BitwiseXorAssign

^=.



Question

?.



Colon

:.



Dot

..



Arrow

->.



LeftParen

(.



RightParen

).



LeftBrace

{.



RightBrace

}.



LeftBracket

[.



RightBracket

].



Semicolon

;.



Comma

,.



At

@.



Hash

#.



Dollar

$.



Ampersand

&.



Backslash

\.



Quote

'.



DoubleQuote

".



Backtick

`.



Eof

End of file.



Program

A program.



Block

A block.



Variable

A variable declaration.



FunctionCall

A function call.



MethodCall

A method call.



PropertyAccess

A property access.



ArrayAccess

An array access.



ParameterList

A parameter list.



UseItem

A use item.



ModuleItem

A module item.



StructItem

A struct item.



EnumItem

An enum item.



FunctionType

A function type.



Root

The root node.



Statement

A statement.



Expression

An expression.



Assignment

An assignment expression.



ConditionalExpression

A conditional expression.



BinaryExpression

A binary expression.



UnaryExpression

A unary expression.



IfStatement

An if statement.



ForStatement

A for statement.



WhileStatement

A while statement.



DoWhileStatement

A do-while statement.



SwitchStatement

A switch statement.



TryStatement

A try statement.



ThrowStatement

A throw statement.



ReturnStatement

A return statement.



BreakStatement

A break statement.



ContinueStatement

A continue statement.



Error

An error node.



LiteralExpression

A literal expression.



IdentifierExpression

An identifier expression.



ParenthesizedExpression

A parenthesized expression.



SourceFile

A source file.



BlockExpression

A block expression.



LetStatement

A let statement.



IfExpression

An if expression.



WhileExpression

A while expression.



LoopExpression

A loop expression.



ForExpression

A for expression.



CallExpression

A call expression.



IndexExpression

An index expression.



FieldExpression

A field expression.