ActionScriptTokenType

Enum ActionScriptTokenType 

#[repr(u8)]
pub enum ActionScriptTokenType {
Show 176 variants Whitespace = 0, Newline = 1, Comment = 2, Identifier = 3, StringLiteral = 4, CharLiteral = 5, NumberLiteral = 6, BooleanLiteral = 7, NullLiteral = 8, As = 9, Break = 10, Case = 11, Catch = 12, Class = 13, Const = 14, Continue = 15, Default = 16, Delete = 17, Do = 18, Else = 19, Extends = 20, False = 21, Finally = 22, For = 23, Function = 24, If = 25, Implements = 26, Import = 27, In = 28, Instanceof = 29, Interface = 30, Internal = 31, Is = 32, Native = 33, New = 34, Null = 35, Package = 36, Private = 37, Protected = 38, Public = 39, Return = 40, Static = 41, Super = 42, Switch = 43, This = 44, Throw = 45, True = 46, Try = 47, Typeof = 48, Use = 49, Var = 50, Void = 51, While = 52, With = 53, Each = 54, Get = 55, Set = 56, Namespace = 57, Include = 58, Dynamic = 59, Final = 60, Override = 61, Array = 62, Boolean = 63, Date = 64, Number = 65, ObjectType = 66, RegExp = 67, StringType = 68, Uint = 69, Vector = 70, VoidType = 71, Xml = 72, XmlList = 73, Plus = 74, Minus = 75, Star = 76, Slash = 77, Percent = 78, Equal = 79, EqualEqual = 80, EqualEqualEqual = 81, NotEqual = 82, NotEqualEqual = 83, LessThan = 84, LessEqual = 85, GreaterThan = 86, GreaterEqual = 87, LogicalAnd = 88, LogicalOr = 89, LogicalNot = 90, BitwiseAnd = 91, BitwiseOr = 92, BitwiseXor = 93, BitwiseNot = 94, LeftShift = 95, RightShift = 96, UnsignedRightShift = 97, Increment = 98, Decrement = 99, PlusAssign = 100, MinusAssign = 101, StarAssign = 102, SlashAssign = 103, PercentAssign = 104, LeftShiftAssign = 105, RightShiftAssign = 106, UnsignedRightShiftAssign = 107, BitwiseAndAssign = 108, BitwiseOrAssign = 109, BitwiseXorAssign = 110, Question = 111, Colon = 112, Dot = 113, Arrow = 114, LeftParen = 115, RightParen = 116, LeftBrace = 117, RightBrace = 118, LeftBracket = 119, RightBracket = 120, Semicolon = 121, Comma = 122, At = 123, Hash = 124, Dollar = 125, Ampersand = 126, Backslash = 127, Quote = 128, DoubleQuote = 129, Backtick = 130, Eof = 131, Program = 132, Block = 133, Variable = 134, FunctionCall = 135, MethodCall = 136, PropertyAccess = 137, ArrayAccess = 138, ParameterList = 139, UseItem = 140, ModuleItem = 141, StructItem = 142, EnumItem = 143, FunctionType = 144, Root = 145, Statement = 146, Expression = 147, Assignment = 148, ConditionalExpression = 149, BinaryExpression = 150, UnaryExpression = 151, IfStatement = 152, ForStatement = 153, WhileStatement = 154, DoWhileStatement = 155, SwitchStatement = 156, TryStatement = 157, ThrowStatement = 158, ReturnStatement = 159, BreakStatement = 160, ContinueStatement = 161, Error = 162, LiteralExpression = 163, IdentifierExpression = 164, ParenthesizedExpression = 165, SourceFile = 166, BlockExpression = 167, LetStatement = 168, IfExpression = 169, WhileExpression = 170, LoopExpression = 171, ForExpression = 172, CallExpression = 173, IndexExpression = 174, FieldExpression = 175,
}
Token types for the ActionScript language.

Variants



Whitespace = 0

Whitespace characters.



Newline = 1

Newline characters.



Comment = 2

Comments.



Identifier = 3

An identifier.



StringLiteral = 4

A string literal.



CharLiteral = 5

A character literal.



NumberLiteral = 6

A number literal.



BooleanLiteral = 7

A boolean literal.



NullLiteral = 8

A null literal.



As = 9

as keyword.



Break = 10

break keyword.



Case = 11

case keyword.



Catch = 12

catch keyword.



Class = 13

class keyword.



Const = 14

const keyword.



Continue = 15

continue keyword.



Default = 16

default keyword.



Delete = 17

delete keyword.



Do = 18

do keyword.



Else = 19

else keyword.



Extends = 20

extends keyword.



False = 21

false keyword.



Finally = 22

finally keyword.



For = 23

for keyword.



Function = 24

function keyword.



If = 25

if keyword.



Implements = 26

implements keyword.



Import = 27

import keyword.



In = 28

in keyword.



Instanceof = 29

instanceof keyword.



Interface = 30

interface keyword.



Internal = 31

internal keyword.



Is = 32

is keyword.



Native = 33

native keyword.



New = 34

new keyword.



Null = 35

null keyword.



Package = 36

package keyword.



Private = 37

private keyword.



Protected = 38

protected keyword.



Public = 39

public keyword.



Return = 40

return keyword.



Static = 41

static keyword.



Super = 42

super keyword.



Switch = 43

switch keyword.



This = 44

this keyword.



Throw = 45

throw keyword.



True = 46

true keyword.



Try = 47

try keyword.



Typeof = 48

typeof keyword.



Use = 49

use keyword.



Var = 50

var keyword.



Void = 51

void keyword.



While = 52

while keyword.



With = 53

with keyword.



Each = 54

each keyword.



Get = 55

get keyword.



Set = 56

set keyword.



Namespace = 57

namespace keyword.



Include = 58

include keyword.



Dynamic = 59

dynamic keyword.



Final = 60

final keyword.



Override = 61

override keyword.



Array = 62

Array type.



Boolean = 63

Boolean type.



Date = 64

Date type.



Number = 65

Number type.



ObjectType = 66

Object type.



RegExp = 67

RegExp type.



StringType = 68

String type.



Uint = 69

uint type.



Vector = 70

Vector type.



VoidType = 71

void type.



Xml = 72

XML type.



XmlList = 73

XMLList type.



Plus = 74

+ operator.



Minus = 75

- operator.



Star = 76

* operator.



Slash = 77

/ operator.



Percent = 78

% operator.



Equal = 79

= operator.



EqualEqual = 80

== operator.



EqualEqualEqual = 81

=== operator.



NotEqual = 82

!= operator.



NotEqualEqual = 83

!== operator.



LessThan = 84

< operator.



LessEqual = 85

<= operator.



GreaterThan = 86

> operator.



GreaterEqual = 87

>= operator.



LogicalAnd = 88

&& operator.



LogicalOr = 89

|| operator.



LogicalNot = 90

! operator.



BitwiseAnd = 91

& operator.



BitwiseOr = 92

| operator.



BitwiseXor = 93

^ operator.



BitwiseNot = 94

~ operator.



LeftShift = 95

<< operator.



RightShift = 96

>> operator.



UnsignedRightShift = 97

>>> operator.



Increment = 98

++ operator.



Decrement = 99

-- operator.



PlusAssign = 100

+= operator.



MinusAssign = 101

-= operator.



StarAssign = 102

*= operator.



SlashAssign = 103

/= operator.



PercentAssign = 104

%= operator.



LeftShiftAssign = 105

<<= operator.



RightShiftAssign = 106

>>= operator.



UnsignedRightShiftAssign = 107

>>>= operator.



BitwiseAndAssign = 108

&= operator.



BitwiseOrAssign = 109

|= operator.



BitwiseXorAssign = 110

^= operator.



Question = 111

? punctuation.



Colon = 112

: punctuation.



Dot = 113

. punctuation.



Arrow = 114

-> operator.



LeftParen = 115

( punctuation.



RightParen = 116

) punctuation.



LeftBrace = 117

{ punctuation.



RightBrace = 118

} punctuation.



LeftBracket = 119

[ punctuation.



RightBracket = 120

] punctuation.



Semicolon = 121

; punctuation.



Comma = 122

, punctuation.



At = 123

@ punctuation.



Hash = 124

# punctuation.



Dollar = 125

$ punctuation.



Ampersand = 126

& punctuation.



Backslash = 127

\ punctuation.



Quote = 128

' punctuation.



DoubleQuote = 129

" punctuation.



Backtick = 130

` punctuation.



Eof = 131

End of file token.



Program = 132

A program.



Block = 133

A block.



Variable = 134

A variable.



FunctionCall = 135

A function call.



MethodCall = 136

A method call.



PropertyAccess = 137

A property access.



ArrayAccess = 138

An array access.



ParameterList = 139

A parameter list.



UseItem = 140

A use item.



ModuleItem = 141

A module item.



StructItem = 142

A struct item.



EnumItem = 143

An enum item.



FunctionType = 144

A function type.



Root = 145

Root element.



Statement = 146

A statement.



Expression = 147

An expression.



Assignment = 148

An assignment.



ConditionalExpression = 149

A conditional expression.



BinaryExpression = 150

A binary expression.



UnaryExpression = 151

A unary expression.



IfStatement = 152

An if statement.



ForStatement = 153

A for statement.



WhileStatement = 154

A while statement.



DoWhileStatement = 155

A do-while statement.



SwitchStatement = 156

A switch statement.



TryStatement = 157

A try statement.



ThrowStatement = 158

A throw statement.



ReturnStatement = 159

A return statement.



BreakStatement = 160

A break statement.



ContinueStatement = 161

A continue statement.



Error = 162

Error token.



LiteralExpression = 163

A literal expression.



IdentifierExpression = 164

An identifier expression.



ParenthesizedExpression = 165

A parenthesized expression.



SourceFile = 166

A source file.



BlockExpression = 167

A block expression.



LetStatement = 168

A let statement.



IfExpression = 169

An if expression.



WhileExpression = 170

A while expression.



LoopExpression = 171

A loop expression.



ForExpression = 172

A for expression.



CallExpression = 173

A call expression.



IndexExpression = 174

An index expression.



FieldExpression = 175

A field expression.

Implementations

Source

impl ActionScriptTokenType

pub fn is_literal(&self) -> bool

Returns true if the token type is a literal.

pub fn is_keyword(&self) -> bool

Returns true if the token type is a keyword.

pub fn is_operator(&self) -> bool

Returns true if the token type is an operator.

pub fn is_punctuation(&self) -> bool

Returns true if the token type is a punctuation.